@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type, Union
+from typing import Any, Dict, Mapping, Sequence, Type, Union
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -62,7 +62,7 @@ __all__ = ("ComputeOptimizerClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -82,7 +82,7 @@ class Exceptions:
 
 class ComputeOptimizerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html)
     """
 
@@ -98,22 +98,22 @@ class ComputeOptimizerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#can_paginate)
         """
 
     def describe_recommendation_export_jobs(
         self,
         *,
-        jobIds: List[str] = None,
-        filters: List["JobFilterTypeDef"] = None,
+        jobIds: Sequence[str] = None,
+        filters: Sequence["JobFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
         Describes recommendation export jobs created in the last seven days.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#describe_recommendation_export_jobs)
         """
 
@@ -121,9 +121,9 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         s3DestinationConfig: "S3DestinationConfigTypeDef",
-        accountIds: List[str] = None,
-        filters: List["FilterTypeDef"] = None,
-        fieldsToExport: List[ExportableAutoScalingGroupFieldType] = None,
+        accountIds: Sequence[str] = None,
+        filters: Sequence["FilterTypeDef"] = None,
+        fieldsToExport: Sequence[ExportableAutoScalingGroupFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None,
         recommendationPreferences: "RecommendationPreferencesTypeDef" = None
@@ -131,7 +131,7 @@ class ComputeOptimizerClient(BaseClient):
         """
         Exports optimization recommendations for Auto Scaling groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_auto_scaling_group_recommendations)
         """
 
@@ -139,16 +139,16 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         s3DestinationConfig: "S3DestinationConfigTypeDef",
-        accountIds: List[str] = None,
-        filters: List["EBSFilterTypeDef"] = None,
-        fieldsToExport: List[ExportableVolumeFieldType] = None,
+        accountIds: Sequence[str] = None,
+        filters: Sequence["EBSFilterTypeDef"] = None,
+        fieldsToExport: Sequence[ExportableVolumeFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
     ) -> ExportEBSVolumeRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Amazon EBS volumes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ebs_volume_recommendations)
         """
 
@@ -156,9 +156,9 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         s3DestinationConfig: "S3DestinationConfigTypeDef",
-        accountIds: List[str] = None,
-        filters: List["FilterTypeDef"] = None,
-        fieldsToExport: List[ExportableInstanceFieldType] = None,
+        accountIds: Sequence[str] = None,
+        filters: Sequence["FilterTypeDef"] = None,
+        fieldsToExport: Sequence[ExportableInstanceFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None,
         recommendationPreferences: "RecommendationPreferencesTypeDef" = None
@@ -166,7 +166,7 @@ class ComputeOptimizerClient(BaseClient):
         """
         Exports optimization recommendations for Amazon EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ec2_instance_recommendations)
         """
 
@@ -174,80 +174,80 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         s3DestinationConfig: "S3DestinationConfigTypeDef",
-        accountIds: List[str] = None,
-        filters: List["LambdaFunctionRecommendationFilterTypeDef"] = None,
-        fieldsToExport: List[ExportableLambdaFunctionFieldType] = None,
+        accountIds: Sequence[str] = None,
+        filters: Sequence["LambdaFunctionRecommendationFilterTypeDef"] = None,
+        fieldsToExport: Sequence[ExportableLambdaFunctionFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
     ) -> ExportLambdaFunctionRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Lambda functions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_lambda_function_recommendations)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#generate_presigned_url)
         """
 
     def get_auto_scaling_group_recommendations(
         self,
         *,
-        accountIds: List[str] = None,
-        autoScalingGroupArns: List[str] = None,
+        accountIds: Sequence[str] = None,
+        autoScalingGroupArns: Sequence[str] = None,
         nextToken: str = None,
         maxResults: int = None,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         recommendationPreferences: "RecommendationPreferencesTypeDef" = None
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
         Returns Auto Scaling group recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_auto_scaling_group_recommendations)
         """
 
     def get_ebs_volume_recommendations(
         self,
         *,
-        volumeArns: List[str] = None,
+        volumeArns: Sequence[str] = None,
         nextToken: str = None,
         maxResults: int = None,
-        filters: List["EBSFilterTypeDef"] = None,
-        accountIds: List[str] = None
+        filters: Sequence["EBSFilterTypeDef"] = None,
+        accountIds: Sequence[str] = None
     ) -> GetEBSVolumeRecommendationsResponseTypeDef:
         """
         Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ebs_volume_recommendations)
         """
 
     def get_ec2_instance_recommendations(
         self,
         *,
-        instanceArns: List[str] = None,
+        instanceArns: Sequence[str] = None,
         nextToken: str = None,
         maxResults: int = None,
-        filters: List["FilterTypeDef"] = None,
-        accountIds: List[str] = None,
+        filters: Sequence["FilterTypeDef"] = None,
+        accountIds: Sequence[str] = None,
         recommendationPreferences: "RecommendationPreferencesTypeDef" = None
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
         Returns Amazon EC2 instance recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_instance_recommendations)
         """
 
@@ -265,7 +265,7 @@ class ComputeOptimizerClient(BaseClient):
         Returns the projected utilization metrics of Amazon EC2 instance
         recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_recommendation_projected_metrics)
         """
 
@@ -274,14 +274,14 @@ class ComputeOptimizerClient(BaseClient):
         Returns the enrollment (opt in) status of an account to the Compute Optimizer
         service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_enrollment_status)
         """
 
     def get_enrollment_statuses_for_organization(
         self,
         *,
-        filters: List["EnrollmentFilterTypeDef"] = None,
+        filters: Sequence["EnrollmentFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
     ) -> GetEnrollmentStatusesForOrganizationResponseTypeDef:
@@ -289,33 +289,33 @@ class ComputeOptimizerClient(BaseClient):
         Returns the Compute Optimizer enrollment (opt-in) status of organization member
         accounts, if your account is an organization management account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_statuses_for_organization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_statuses_for_organization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_enrollment_statuses_for_organization)
         """
 
     def get_lambda_function_recommendations(
         self,
         *,
-        functionArns: List[str] = None,
-        accountIds: List[str] = None,
-        filters: List["LambdaFunctionRecommendationFilterTypeDef"] = None,
+        functionArns: Sequence[str] = None,
+        accountIds: Sequence[str] = None,
+        filters: Sequence["LambdaFunctionRecommendationFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
     ) -> GetLambdaFunctionRecommendationsResponseTypeDef:
         """
         Returns Lambda function recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_lambda_function_recommendations)
         """
 
     def get_recommendation_summaries(
-        self, *, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
+        self, *, accountIds: Sequence[str] = None, nextToken: str = None, maxResults: int = None
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
         Returns the optimization findings for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_recommendation_summaries)
         """
 
@@ -326,6 +326,6 @@ class ComputeOptimizerClient(BaseClient):
         Updates the enrollment (opt in and opt out) status of an account to the Compute
         Optimizer service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#update_enrollment_status)
         """
